@@ -1,16 +1,19 @@
 package Devel::AssertOS::Unix;
 
 use Devel::CheckOS;
+use strict;
+use warnings;
+no warnings 'redefine';
 
-$VERSION = '1.5';
+our $VERSION = '1.6';
 
 # list of OSes originally lifted from Module::Build 0.2808
 #
 sub matches {
     return qw(
-        AIX Bitrig BSDOS DGUX DragonflyBSD Dynix FreeBSD HPUX Interix Irix
-        Linux MachTen MacOSX MirOSBSD NetBSD OpenBSD OSF QNX SCO Solaris
-        SunOS SysVr4 SysVr5 Unicos MidnightBSD
+        AIX Android Bitrig BSDOS DGUX DragonflyBSD Dynix FreeBSD HPUX Interix
+        iOS Irix Linux MachTen MacOSX Minix MirOSBSD NetBSD OpenBSD OSF QNX SCO
+        Solaris SunOS SysVr4 SysVr5 Unicos MidnightBSD
     );
 }
 sub os_is { Devel::CheckOS::os_is(matches()); }
@@ -22,7 +25,9 @@ join("\n",
 "pseudo-files in /dev, there is a single root to the filesystem, users",
 "are protected from interference from other users, and the API is POSIXy.",
 "It should be reasonably easy to port a simple text-mode C program",
-"between Unixes."
+"between Unixes.\n",
+"In some cases (eg Android, iOS) this might not be obvious or be exposed",
+"to users."
 )
 }
 
